@@ -1,8 +1,8 @@
 #!@SHELL@
 
 # Don't hack this script by hand if it's in one of your PATH directories.
-# Instead, modify the pre-script in the YODL source package and do a 
-# "make installscripts".
+# Instead, modify scripts/yodl2msps.sh in the YODL source package and do
+# "make -C scripts install".
 
 #################################################### Print error msg and die.
 error()
@@ -51,8 +51,14 @@ if [ "$inf" = "" ] ; then
 fi
 
 # determine output file, logfile, dvi file
-msf=${inf%%.yo}.ms
-psf=${inf%%.yo}.ps
+# ash chokes on these
+#if [ "x${inf%%.yo}.yo" = "x$inf".yo ]; then
+#    msf=${inf%%.yo}.ms
+#    psf=${inf%%.yo}.ps
+#else
+    msf=`echo $inf | sed 's/\.yo//'`.ms
+    psf=`echo $inf | sed 's/\.yo//'`.ps
+#fi
 
 yodl2ms $flags $inf || error "YODL to LaTeX conversion failed"
 @MSTOPS@ $msf > $psf || error "ms to PostScript conversion failed"
