@@ -3,6 +3,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include "config.h"
 
 /* Use prototypes if available.  */
 #if defined (__cplusplus) || (defined (__STDC__) && __STDC__)
@@ -21,6 +22,12 @@
     extern char *realloc PARAMS ((char*, int));
 #endif
 
+#if 0  /* urg, this is a weird type of basename (), at least on glibc */
+#if HAVE_LIBGEN_H
+#   include <libgen.h>
+#endif
+#endif
+
 extern void close_file (FILE * f);
 extern void error (char const *fmt,...);
 extern void error_setprogname (char const *fmt);
@@ -30,10 +37,27 @@ extern char *str_addchar (char *str, int ch);
 extern char *str_concat (char *str, char const *tail);
 extern char *str_replace (char *str, char const *search, char const *replace);
 extern char *str_short (char const *s);
+
+#if ! HAVE_HSEARCH_R
+#define strarr_add strtab_add
+#define strarr_del strtab_del
+#define strarr_find strtab_find
+#define strarr_free strtab_free
+#else
+/* urg, glibc-2.1 needs this */
+#define __USE_GNU
+#endif
+
+extern char **strarr_add (char **tab, int *ntab, char const *newstr);
+extern void strarr_del (char **tab, int *ntab, char const *what);
+extern int strarr_find (char **tab, int ntab, char const *string);
+extern void strarr_free (char **tab, int ntab);
+
 extern char **strtab_add (char **tab, int *ntab, char const *newstr);
 extern void strtab_del (char **tab, int *ntab, char const *what);
 extern int strtab_find (char **tab, int ntab, char const *string);
 extern void strtab_free (char **tab, int ntab);
+
 extern void warning (char const *fmt,...);
 extern void *xrealloc (void *mem, int newsz);
 extern char *xstrdup (char const *s);
