@@ -5,12 +5,15 @@ void
 error_gram (char const *rule, char const *msg,...)
 {
   va_list args;
+  char* symbol;
 
   /* urg, duplicate code in error_gram */
   if (!lexbuf || !*lexbuf)
-    lexbuf = "<empty>";
+    symbol = "<empty>";
   else if (*lexbuf == '\n')
-    lexbuf = "<newline>";
+    symbol = "<newline>";
+  else
+    symbol = lexbuf;
 
   /*
     use GNU style message
@@ -21,7 +24,7 @@ error_gram (char const *rule, char const *msg,...)
   va_start (args, msg);
   gnu_vmessage (msg, args);
   va_end (args);
-  gnu_message ("last parsed symbol: `%s'", lexbuf);
+  gnu_message ("last parsed symbol: `%s'", symbol);
 
   exit (1);
 }
