@@ -5,9 +5,9 @@ void
 gram_ATEXIT ()
 {
   char
-   *list = gram_parlist (builtin[idx_ATEXIT], 0);
+   *list = gram_parlist (builtin_get (idx_ATEXIT), 0);
 
-  message (3, "%s %s\n", builtin[idx_ATEXIT], str_short (list));
+  message (3, "%s %s\n", builtin_get (idx_ATEXIT), str_short (list));
 
   atexit_strings = strtab_add (atexit_strings, &natexit_strings, list);
 
