@@ -7,12 +7,12 @@ gram_CHDIR ()
   char
    *dirname;
 
-  dirname = gram_parlist (builtin[idx_CHDIR], 0);
-  gram_onename (builtin[idx_CHDIR], dirname);
+  dirname = gram_parlist (builtin_get (idx_CHDIR), 0);
+  gram_onename (builtin_get (idx_CHDIR), dirname);
   message (2, "changing to dir: %s\n", dirname);
 
   if (chdir (dirname))
-    error_gram (builtin[idx_CHDIR], "cannot chdir to %s: %s",
+    error_gram (builtin_get (idx_CHDIR), "cannot chdir to %s: %s",
 		dirname, strerror (errno));
 
   free (dirname);
