@@ -9,10 +9,10 @@ gram_COUNTERVALUE ()
   char
    *name, buf[80];
 
-  name = gram_parlist (builtin[idx_COUNTERVALUE], 0);
-  index = gram_findcounter (builtin[idx_COUNTERVALUE], name);
+  name = gram_parlist (builtin_get (idx_COUNTERVALUE), 0);
+  index = gram_findcounter (builtin_get (idx_COUNTERVALUE), name);
 
-  message (3, "%s %s: %d\n", builtin[idx_COUNTERVALUE], name,
+  message (3, "%s %s: %d\n", builtin_get (idx_COUNTERVALUE), name,
 	   counterval[index]);
 
   sprintf (buf, "%d", counterval[index]);
