@@ -79,7 +79,7 @@ parse_table (char *table, CHARTAB * dest)
   line = strtok (table, "\n");
   while (line)
     {
-      lines = strtab_add (lines, &nlines, line);
+      lines = strarr_add (lines, &nlines, line);
       line = strtok (0, "\n");
     }
 
@@ -87,43 +87,43 @@ parse_table (char *table, CHARTAB * dest)
     {
       newchar = strtok (lines[i], "=");
       if (!newchar)
-	error_gram (builtin[idx_DEFINECHARTABLE],
+	error_gram (builtin_get (idx_DEFINECHARTABLE),
 		    "missing character specifier in line %s", lines[i]);
       while (isspace ((int)*newchar))
 	newchar++;
       newredef = strtok (0, "=");
       if (!newredef)
-	error_gram (builtin[idx_DEFINECHARTABLE],
+	error_gram (builtin_get (idx_DEFINECHARTABLE),
 		    "missing redefinition specifier in line %s", lines[i]);
       while (isspace ((int)*newredef))
 	newredef++;
 
-      charp = strtab_add (charp, &ncharp, newchar);
-      redefp = strtab_add (redefp, &nredefp, newredef);
+      charp = strarr_add (charp, &ncharp, newchar);
+      redefp = strarr_add (redefp, &nredefp, newredef);
     }
 
   for (i = 0; i < nlines; i++)
     {
       if ((chindex = string_to_char (charp[i])) == -1)
-	error_gram (builtin[idx_DEFINECHARTABLE],
+	error_gram (builtin_get (idx_DEFINECHARTABLE),
 		    "at %s: expected 'c' character specifier", charp[i]);
 
       if (*redefp[i] != '"' || !*(redefp[i] + 1))
-	error_gram (builtin[idx_DEFINECHARTABLE],
+	error_gram (builtin_get (idx_DEFINECHARTABLE),
 		    "redefinition %s: must have form \"redef\"", redefp);
       strcpy (redefp[i], redefp[i] + 1);
       redeflen = strlen (redefp[i]) - 1;
       if (redefp[i][redeflen] != '"')
-	error_gram (builtin[idx_DEFINECHARTABLE],
+	error_gram (builtin_get (idx_DEFINECHARTABLE),
 		    "redefinition %s: unterminated string", redefp[i]);
       redefp[i][redeflen] = '\0';
 
       (*dest)[chindex] = string_to_string (redefp[i]);
     }
 
-  strtab_free (lines, nlines);
-  strtab_free (charp, ncharp);
-  strtab_free (redefp, nredefp);
+  strarr_free (lines, nlines);
+  strarr_free (charp, ncharp);
+  strarr_free (redefp, nredefp);
 }
 
 void
@@ -141,10 +141,10 @@ gram_DEFINECHARTABLE ()
 
 
   tabname =			/* retrieve table name */
-    gram_parlist (builtin[idx_DEFINECHARTABLE], 0);
-  gram_onename (builtin[idx_DEFINECHARTABLE], tabname);
+    gram_parlist (builtin_get (idx_DEFINECHARTABLE), 0);
+  gram_onename (builtin_get (idx_DEFINECHARTABLE), tabname);
 
-  message (3, "%s %s\n", builtin[idx_DEFINECHARTABLE], tabname);
+  message (3, "%s %s\n", builtin_get (idx_DEFINECHARTABLE), tabname);
 
   while (lextok == tok_space ||	/* skip spaces, newlines */
 	 lextok == tok_newline
@@ -152,14 +152,14 @@ gram_DEFINECHARTABLE ()
     lexer ();
 
   table =			/* retrieve table itself */
-    gram_parlist (builtin[idx_DEFINECHARTABLE], 0);
+    gram_parlist (builtin_get (idx_DEFINECHARTABLE), 0);
   if (!table || !*table)	/* may not be empty */
-    error_gram (builtin[idx_DEFINECHARTABLE],
+    error_gram (builtin_get (idx_DEFINECHARTABLE),
 		"empty table definition for table %s", tabname);
 
   /* table already defined? */
   if (strtab_find (chartabname, nchartab, tabname) != -1)
-    error_gram (builtin[idx_DEFINECHARTABLE],
+    error_gram (builtin_get (idx_DEFINECHARTABLE),
 		"table %s already defined", tabname);
 
   i = curchartab - chartab;	/* remember current */
