@@ -9,20 +9,20 @@ gram_IFSTREQUAL ()
   int
     res;
 
-  str1 = gram_parlist (builtin[idx_IFSTREQUAL], 0);
-  message (3, "%s %s\n", builtin[idx_IFSTREQUAL], str_short (str1));
+  str1 = gram_parlist (builtin_get (idx_IFSTREQUAL), 0);
+  message (3, "%s %s\n", builtin_get (idx_IFSTREQUAL), str_short (str1));
 
   while (lextok == tok_space || lextok == tok_newline)
     lexer ();
-  str2 = gram_parlist (builtin[idx_IFSTREQUAL], 0);
+  str2 = gram_parlist (builtin_get (idx_IFSTREQUAL), 0);
 
   while (lextok == tok_space || lextok == tok_newline)
     lexer ();
-  truelist = gram_parlist (builtin[idx_IFSTREQUAL], 0);
+  truelist = gram_parlist (builtin_get (idx_IFSTREQUAL), 0);
 
   while (lextok == tok_space || lextok == tok_newline)
     lexer ();
-  falselist = gram_parlist (builtin[idx_IFSTREQUAL], 0);
+  falselist = gram_parlist (builtin_get (idx_IFSTREQUAL), 0);
   lexer_pushstr (lexbuf);
 
   if (!str1)
