@@ -10,20 +10,20 @@ gram_IFSTRSUB ()
   int
     res;
 
-  str1 = gram_parlist (builtin[idx_IFSTRSUB], 0);
-  message (3, "%s %s\n", builtin[idx_IFSTRSUB], str_short (str1));
+  str1 = gram_parlist (builtin_get (idx_IFSTRSUB), 0);
+  message (3, "%s %s\n", builtin_get (idx_IFSTRSUB), str_short (str1));
 
   while (lextok == tok_space || lextok == tok_newline)
     lexer ();
-  str2 = gram_parlist (builtin[idx_IFSTRSUB], 0);
+  str2 = gram_parlist (builtin_get (idx_IFSTRSUB), 0);
 
   while (lextok == tok_space || lextok == tok_newline)
     lexer ();
-  truelist = gram_parlist (builtin[idx_IFSTRSUB], 0);
+  truelist = gram_parlist (builtin_get (idx_IFSTRSUB), 0);
 
   while (lextok == tok_space || lextok == tok_newline)
     lexer ();
-  falselist = gram_parlist (builtin[idx_IFSTRSUB], 0);
+  falselist = gram_parlist (builtin_get (idx_IFSTRSUB), 0);
   lexer_pushstr (lexbuf);
 
   if (!str1)
