@@ -10,22 +10,22 @@ gram_IFZERO ()
   int
     slot, nr;
   /* get symbol, true-, falselist */
-  symbol = gram_parlist (builtin[idx_IFZERO], 0);
-  message (3, "%s %s\n", builtin[idx_IFZERO], str_short (symbol));
+  symbol = gram_parlist (builtin_get (idx_IFZERO), 0);
+  message (3, "%s %s\n", builtin_get (idx_IFZERO), str_short (symbol));
 
   while (lextok == tok_space ||	/* skip spaces, newlines */
 	 lextok == tok_newline
     )
     lexer ();
 
-  truelist = gram_parlist (builtin[idx_IFZERO], 0);
+  truelist = gram_parlist (builtin_get (idx_IFZERO), 0);
 
   while (lextok == tok_space ||	/* skip spaces, newlines */
 	 lextok == tok_newline
     )
     lexer ();
 
-  falselist = gram_parlist (builtin[idx_IFZERO], 0);
+  falselist = gram_parlist (builtin_get (idx_IFZERO), 0);
 
   lexer_pushstr (lexbuf);	/* push back beyond parlist */
 
