@@ -15,13 +15,17 @@ gram_INCLUDEFILE ()
   TOKEN
     old_lextok;
 
+  /* jcn-hsearch?? */
+  char *old_lexer_pushed;
+  char *old_lexer_pushedp;
+
   include_level++;
   if (include_level > maxpass)	/* recursive? */
     error_gram ("%s", "nesting depth exceeds %d",
-		builtin[idx_INCLUDEFILE], maxpass);
+		builtin_get (idx_INCLUDEFILE), maxpass);
 
-  name = gram_parlist (builtin[idx_INCLUDEFILE], 0);
-  gram_onename (builtin[idx_INCLUDEFILE], name);
+  name = gram_parlist (builtin_get (idx_INCLUDEFILE), 0);
+  gram_onename (builtin_get (idx_INCLUDEFILE), name);
   realname = file_expandname (name);
   message (2, "including file: %s\n", realname);
   free (name);
@@ -40,8 +44,19 @@ gram_INCLUDEFILE ()
 
   old_lextok = lextok;
 
+  /* jcn-hsearch?? */
+  old_lexer_pushed = lexer_pushed;
+  lexer_pushed = 0;
+
+  old_lexer_pushedp = lexer_pushedp;
+  lexer_pushedp = 0;
+
   parse ();
 
+  /* jcn-hsearch?? */
+  lexer_pushed = old_lexer_pushed;
+  lexer_pushedp = old_lexer_pushedp;
+
   lextok = old_lextok;
 
   free (lexbuf);
