@@ -15,8 +15,8 @@ gram_INCLUDELIT ()
   FILE
     * old_inf;
 
-  name = gram_parlist (builtin[idx_INCLUDELIT], 0);
-  gram_onename (builtin[idx_INCLUDELIT], name);
+  name = gram_parlist (builtin_get (idx_INCLUDELIT), 0);
+  gram_onename (builtin_get (idx_INCLUDELIT), name);
 
   message (2, "including literal file: %s\n", name);
 
