@@ -9,8 +9,8 @@ gram_NOTRANS ()
   CHARTAB
     * old_curchartab;
 
-  list = gram_parlist (builtin[idx_NOTRANS], 1);
-  message (3, "%s %s\n", builtin[idx_NOTRANS], str_short (list));
+  list = gram_parlist (builtin_get (idx_NOTRANS), 1);
+  message (3, "%s %s\n", builtin_get (idx_NOTRANS), str_short (list));
 
   old_curchartab = curchartab;
   curchartab = 0;
