@@ -23,7 +23,7 @@ gram_PIPETHROUGH ()
   struct stat
     statbuf;
 
-  cmd = gram_parlist (builtin[idx_PIPETHROUGH], 1);
+  cmd = gram_parlist (builtin_get (idx_PIPETHROUGH), 1);
   cmd = gram_do_expand (cmd);
 
   /*
@@ -35,11 +35,11 @@ gram_PIPETHROUGH ()
          || (lextok == tok_newline))
     lexer ();
 
-  pipeto = gram_parlist (builtin[idx_PIPETHROUGH], 1);
+  pipeto = gram_parlist (builtin_get (idx_PIPETHROUGH), 1);
 
-  message (3, "%s %s | %s\n", builtin[idx_PIPETHROUGH], str_short (cmd), str_short (pipeto)); 
+  message (3, "%s %s | %s\n", builtin_get (idx_PIPETHROUGH), str_short (cmd), str_short (pipeto)); 
 	   
-  if (!check_live_data (builtin[idx_PIPETHROUGH], cmd))
+  if (!check_live_data (builtin_get (idx_PIPETHROUGH), cmd))
     {
       free (cmd);
       free (pipeto);
@@ -151,7 +151,7 @@ gram_PIPETHROUGH ()
   int out[2];
   int child_pid;
 
-  filter_cmd = gram_parlist (builtin[idx_PIPETHROUGH], 1);
+  filter_cmd = gram_parlist (builtin_get (idx_PIPETHROUGH), 1);
   filter_cmd = gram_do_expand (filter_cmd);
 
   /*
@@ -163,11 +163,11 @@ gram_PIPETHROUGH ()
          || (lextok == tok_newline))
     lexer ();
 
-  to_filter = gram_parlist (builtin[idx_PIPETHROUGH], 1);
+  to_filter = gram_parlist (builtin_get (idx_PIPETHROUGH), 1);
 
-  message (3, "%s %s | %s\n", builtin[idx_PIPETHROUGH], str_short (filter_cmd), str_short (to_filter)); 
+  message (3, "%s %s | %s\n", builtin_get (idx_PIPETHROUGH), str_short (filter_cmd), str_short (to_filter)); 
 	   
-  if (!check_live_data (builtin[idx_PIPETHROUGH], filter_cmd))
+  if (!check_live_data (builtin_get (idx_PIPETHROUGH), filter_cmd))
     {
       free (filter_cmd);
       free (to_filter);
