@@ -5,13 +5,13 @@ void
 gram_POPCHARTABLE ()
 {
   char
-   *list = gram_parlist (builtin[idx_POPCHARTABLE], 0);
+   *list = gram_parlist (builtin_get (idx_POPCHARTABLE), 0);
 
-  message (3, "%s\n", builtin[idx_POPCHARTABLE]);
+  message (3, "%s\n", builtin_get (idx_POPCHARTABLE));
   free (list);
 
   if (nchartabstack <= 0)
-    error_gram (builtin[idx_POPCHARTABLE],
+    error_gram (builtin_get (idx_POPCHARTABLE),
 		"character table stack underflow, can't pop");
 
   curchartab = chartabstack[--nchartabstack];
