@@ -13,18 +13,18 @@ gram_PUSHCHARTABLE ()
   CHARTAB
     * newtab;
 
-  tabname = gram_parlist (builtin[idx_PUSHCHARTABLE], 0);
+  tabname = gram_parlist (builtin_get (idx_PUSHCHARTABLE), 0);
 
-  message (3, "%s %s\n", builtin[idx_PUSHCHARTABLE],
+  message (3, "%s %s\n", builtin_get (idx_PUSHCHARTABLE),
 	   tabname && *tabname ? tabname : "zero-state");
 
   if (!tabname || !*tabname)	/* find char table */
     newtab = 0;
   else
     {
-      gram_onename (builtin[idx_PUSHCHARTABLE], tabname);
+      gram_onename (builtin_get (idx_PUSHCHARTABLE), tabname);
       if ((index = strtab_find (chartabname, nchartab, tabname)) == -1)
-	error_gram (builtin[idx_PUSHCHARTABLE], "no table %s defined",
+	error_gram (builtin_get (idx_PUSHCHARTABLE), "no table %s defined",
 		    tabname);
       newtab = chartab + index;
     }
