@@ -9,20 +9,20 @@ gram_RENAMEMACRO ()
   int
     index;
 
-  macname = gram_parlist (builtin[idx_RENAMEMACRO], 0);
-  gram_onename (builtin[idx_RENAMEMACRO], macname);
+  macname = gram_parlist (builtin_get (idx_RENAMEMACRO), 0);
+  gram_onename (builtin_get (idx_RENAMEMACRO), macname);
 
   while (lextok == tok_space ||	/* skip spaces, newlines */
 	 lextok == tok_newline
     )
     lexer ();
 
-  newname = gram_parlist (builtin[idx_RENAMEMACRO], 0);
-  gram_onename (builtin[idx_RENAMEMACRO], newname);
+  newname = gram_parlist (builtin_get (idx_RENAMEMACRO), 0);
+  gram_onename (builtin_get (idx_RENAMEMACRO), newname);
 
-  message (3, "%s %s %s\n", builtin[idx_RENAMEMACRO], macname, newname);
+  message (3, "%s %s %s\n", builtin_get (idx_RENAMEMACRO), macname, newname);
 
-  if ((index = strtab_find (builtin, nbuiltin, macname)) >= 0)
+  if ((index = strarr_find (builtin, nbuiltin, macname)) >= 0)
     {
       free (builtin[index]);
       builtin[index] = newname;
@@ -33,7 +33,7 @@ gram_RENAMEMACRO ()
       userdef[index] = newname;
     }
   else
-    error_gram (builtin[idx_RENAMEMACRO],
+    error_gram (builtin_get (idx_RENAMEMACRO),
 		"cannot find macro named %s", macname);
 
   free (macname);
