@@ -7,14 +7,14 @@ gram_SUBST ()
   char
    *s, *r;
 
-  s = gram_parlist (builtin[idx_SUBST], 1);	/* read source string */
+  s = gram_parlist (builtin_get (idx_SUBST), 1);	/* read source string */
 
   while (lextok == tok_space ||	/* skip spaces, newlines */
 	 lextok == tok_newline
     )
     lexer ();
 
-  r = gram_parlist (builtin[idx_SUBST], 0);	/* read redefinition */
+  r = gram_parlist (builtin_get (idx_SUBST), 0);	/* read redefinition */
 
   subst = strtab_add (subst, &nsubst, s);	/* add to tables */
   nsubst--;			/* (for next strtab_add) */
