@@ -9,13 +9,13 @@ gram_UPPERCASE ()
   int
     maxlen, i;
 
-  string = gram_parlist (builtin[idx_UPPERCASE], 1);
+  string = gram_parlist (builtin_get (idx_UPPERCASE), 1);
   while (lextok == tok_space ||
 	 lextok == tok_newline
     )
     lexer ();
-  max = gram_parlist (builtin[idx_UPPERCASE], 1);
-  maxlen = gram_onenumber (builtin[idx_UPPERCASE], max);
+  max = gram_parlist (builtin_get (idx_UPPERCASE), 1);
+  maxlen = gram_onenumber (builtin_get (idx_UPPERCASE), max);
 
   /* urg: cast to int */
   if (maxlen < 1 || maxlen > (int)strlen (string))
