@@ -11,13 +11,13 @@ gram_USECOUNTER ()
   char
     buf[80];
 
-  name = gram_parlist (builtin[idx_USECOUNTER], 0);
-  index = gram_findcounter (builtin[idx_USECOUNTER], name);
+  name = gram_parlist (builtin_get (idx_USECOUNTER), 0);
+  index = gram_findcounter (builtin_get (idx_USECOUNTER), name);
 
   (counterval[index])++;
 
   message (3, "%s %s: now %d\n",
-	   builtin[idx_USECOUNTER], name, counterval[index]);
+	   builtin_get (idx_USECOUNTER), name, counterval[index]);
 
   lexer_pushstr (lexbuf);	/* push back beyond parlist */
   sprintf (buf, "%d", counterval[index]);
