@@ -9,9 +9,9 @@ gram_WARNING ()
   int
     oldwarnflag;		/* previous warning flag */
 
-  msg = gram_parlist (builtin[idx_WARNING], 0);
+  msg = gram_parlist (builtin_get (idx_WARNING), 0);
 
-  message (3, "%s %s\n", builtin[idx_WARNING], str_short (msg));
+  message (3, "%s %s\n", builtin_get (idx_WARNING), str_short (msg));
 
   oldwarnflag = flags.warn;	/* save old warning flag */
   flags.warn = 1;		/* make sure warnings printed */
