@@ -8,9 +8,9 @@ gram_WRITEOUT ()
   char* name;
   FILE* file;
 
-  name = gram_parlist (builtin[idx_WRITEOUT], 1);
-  msg = gram_parlist (builtin[idx_WRITEOUT], 1);
-  message (3, "%s %s %s\n", builtin[idx_WRITEOUT], str_short (name), 
+  name = gram_parlist (builtin_get (idx_WRITEOUT), 1);
+  msg = gram_parlist (builtin_get (idx_WRITEOUT), 1);
+  message (3, "%s %s %s\n", builtin_get (idx_WRITEOUT), str_short (name), 
     str_short (msg));
   name = gram_do_expand (name);
 
