@@ -21,7 +21,7 @@ gram_hasident (char const *s)
 
   if
     (
-      strtab_find (builtin, nbuiltin, id) > -1 ||
+      strarr_find (builtin, nbuiltin, id) > -1 ||
       strtab_find (userdef, nuserdef, id) > -1
     )
     res = 1;
