@@ -1,5 +1,6 @@
 
 
+#include "config.h"
 #include "yodl.h"
 
 #include "builtins.c"
@@ -34,10 +35,35 @@ builtin_idx (char const* name)
 }
 #endif
 
+#if 0
+
+#if !  HAVE_HSEARCH_R
+
+char*
+builtin_get (int i)
+{
+  return builtin[i];
+}
+
+#else /* HAVE_HSEARCH_R */
+
+char*
+builtin_get (int i)
+{
+#if 0
+  return strtab_find (builtin, nbuiltin, builtins[i].name);
+#endif
+  return builtins[i].name;
+}
+
+#endif /* HAVE_HSEARCH_R */
+
+#endif
+
 void
 gram_symbol ()			/* handle SYM(blabla) */
 {
-  int symindex = strtab_find (builtin, nbuiltin, lexbuf);
+  int symindex = strarr_find (builtin, nbuiltin, lexbuf);
 
   if (symindex >= 0)            /* if builtin function: */
     {
