@@ -5,15 +5,19 @@ void
 gram_warn (char const *rule, char const *msg,...)
 {
   va_list args;
+  char* symbol;
 
   if (!flags.warn)
     return;
 
   /* urg, duplicate code in error_gram */
   if (!lexbuf || !*lexbuf)
-    lexbuf = "<empty>";
+    symbol = "<empty>";
   else if (*lexbuf == '\n')
-    lexbuf = "<newline>";
+    symbol = "<newline>";
+  else
+    symbol = lexbuf;
+
 
   /*
     use GNU style message
@@ -24,6 +28,6 @@ gram_warn (char const *rule, char const *msg,...)
   va_start (args, msg);
   gnu_vwarning (msg, args);
   va_end (args);
-  gnu_warning ("last parsed symbol: `%s'", lexbuf);
+  gnu_warning ("last parsed symbol: `%s'", symbol);
 }
 
