@@ -43,7 +43,7 @@ output_string (char const *s)
       if (is_ws)		/* if all whitespace: */
 	return;			/* done here */
       else			/* not all ws: warn */
-	gram_warn (builtin[idx_STARTDEF],
+	gram_warn (builtin_get (idx_STARTDEF),
 		   "generated output inside DEF code");
     }
 
