@@ -135,7 +135,7 @@ add_user_defed_macro (char *arg)
   /* ugh C&P*/
   
   if (strtab_find (userdef, nuserdef, macname) != -1)
-    error_gram (builtin[idx_DEFINEMACRO], "macro %s is already defined",
+    error_gram (builtin_get (idx_DEFINEMACRO), "macro %s is already defined",
 		macname);
 
   
