@@ -1,6 +1,8 @@
 
 #include "yodl.h"
 
+#if ! HAVE_HSEARCH_R
+
 int 
 subst_mightbe (char const *s)
 {
@@ -15,3 +17,14 @@ subst_mightbe (char const *s)
 
   return (0);
 }
+
+
+#else /* HAVE_HSEARCH_R */
+
+int
+subst_mightbe (char const *s)
+{
+  return 1;
+}
+
+#endif
