@@ -41,6 +41,11 @@ struct Builtin
   };
 
 struct Builtin* builtin_find (char const* name);
+#if 0
+char* builtin_get (int i);
+#else
+#define builtin_get(x) builtin[x]
+#endif
 
 #include "builtins.h"
 
