@@ -9,7 +9,7 @@ main (int argc, char **argv)
     usage ();
 
   fname = argv[1];
-  fbase = basename (fname);
+  fbase = xstrdup (basename (fname));
 
   init ();			/* global initializations */
 
