@@ -14,7 +14,7 @@ handletag (char *buf, int pass)
   cp = strtok (buf, " \t\n");	/* split up into table */
   while (cp)
     {
-      table = strtab_add (table, &ntable, cp);
+      table = strarr_add (table, &ntable, cp);
       if (cp && !strcmp (cp, TAGEND))
 	break;
       cp = strtok (NULL, " \t\n");
@@ -51,5 +51,5 @@ handletag (char *buf, int pass)
   else if (pass)
     dumptable (table, 0, ntable);	/* dump to output */
 
-  strtab_free (table, ntable);
+  strarr_free (table, ntable);
 }
