@@ -12,6 +12,6 @@ label (char **tab, int ntab, int pass)
   if (pass == FIRSTPASS)
     {
       lab = strtab_add (lab, &nlab, tab[2]);
-      num = strtab_add (num, &nnum, lastnum);
+      num = strarr_add (num, &nnum, lastnum);
     }
 }
